==> plplot-5.10.0.tar.gz: plplot-5.10.0/doc/doxygen/html/search/variables_75.js <==
var searchData=
[
  ['uline',['uline',['../structPLCairo.html#a9fc98c50143c2b0df5c850e58800a4ef',1,'PLCairo']]],
  ['umx',['umx',['../structPLStream.html#abe2d9205f9174884d74a322c6cc78fe7',1,'PLStream']]],
  ['umy',['umy',['../structPLStream.html#afd954dba26f50f0e747c8b6d8daf193f',1,'PLStream']]],
  ['underlined',['underlined',['../classwxPLDevBase.html#a0d1576bedd2aaaba8ab3674cb4f64682',1,'wxPLDevBase::underlined()'],['../classQtPLDriver.html#ac3ba463b209a5b7664c1fadc964b7641',1,'QtPLDriver::underlined()']]],
  ['unicode',['Unicode',['../structHershey__to__Unicode__table.html#a63927014341b3ba1eec039c34b7cfcb6',1,'Hershey_to_Unicode_table::Unicode()'],['../structUnicode__to__Type1__table.html#afc981b330d66e7885e6452356674822a',1,'Unicode_to_Type1_table::Unicode()']]],
  ['unicode_5farray',['unicode_array',['../structEscText.html#ac5ed6a599aa6688ea4e016d5cf9184d7',1,'EscText']]],
  ['unicode_5farray_5flen',['unicode_array_len',['../structEscText.html#a0226f7ca906eec56ae4068ba37a8542b',1,'EscText']]],
  ['unicode_5fbuffer',['unicode_buffer',['../plcore_8c.html#abc490f7a97e538ac7fa480678647fbfd',1,'plcore.c']]],
  ['unicode_5fchar',['unicode_char',['../structEscText.html#ac56ff5804691c224408db9af7c99ecc0',1,'EscText']]],
  ['unicode_5fto_5fdingbats_5flookup_5ftable',['unicode_to_dingbats_lookup_table',['../plunicode-type1_8h.html#a674af18dbdc988c6def70b72f208d90b',1,'plunicode-type1.h']]],
  ['unicode_5fto_5fstandard_5flookup_5ftable',['unicode_to_standard_lookup_table',['../plunicode-type1_8h.html#ade7c8b0082f182f1b4f4cd0c12fab4b9',1,'plunicode-type1.h']]],
  ['unicode_5fto_5fsymbol_5flookup_5ftable',['unicode_to_symbol_lookup_table',['../plunicode-type1_8h.html#a158045056cf63af57aaebb2808629206',1,'plunicode-type1.h']]],
  ['updatecmd',['updatecmd',['../structTkDev.html#a5392c715a876c5d53e17e3a2f468e443',1,'TkDev']]],
  ['updown',['upDown',['../structPLCairo.html#acc53ff3dfd75bceb46c5647814f127d0',1,'PLCairo']]],
  ['urx',['urx',['../structPSDev.html#aa759c208dcaeaebf15e491a48e20de99',1,'PSDev']]],
  ['ury',['ury',['../structPSDev.html#a2a413bbcb369b38931eb0b95f64f5add',1,'PSDev']]],
  ['usage',['usage',['../plargs_8c.html#aef1bd6ad890a110b466cb0e8088507a2',1,'plargs.c']]],
  ['use_5fpersistence',['use_persistence',['../structGcwPLdev.html#a052ed9a591cc873502ca81e0b6ffb577',1,'GcwPLdev']]],
  ['use_5fpixmap',['use_pixmap',['../structGcwPLdev.html#a27fa6673edb596962c49dde8839d8bf5',1,'GcwPLdev']]],
  ['user',['user',['../structPLStream.html#a2c45ef41fca4c2716c99b911c9c8d671',1,'PLStream']]],
  ['utmp',['utmp',['../plot3d_8c.html#a7e3aab59224e9c6116d2c8cc2243fac1',1,'plot3d.c']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/variables_75.js <==
var searchData=
[
  ['uline',['uline',['../structPLCairo.html#a9fc98c50143c2b0df5c850e58800a4ef',1,'PLCairo']]],
  ['umx',['umx',['../structPLStream.html#abe2d9205f9174884d74a322c6cc78fe7',1,'PLStream']]],
  ['umy',['umy',['../structPLStream.html#afd954dba26f50f0e747c8b6d8daf193f',1,'PLStream']]],
  ['underlined',['underlined',['../structTextSizeInfo.html#acf6aa71074a2c3e32d0b286c0b24b9c6',1,'TextSizeInfo::underlined()'],['../classQtPLDriver.html#ac3ba463b209a5b7664c1fadc964b7641',1,'QtPLDriver::underlined()']]],
  ['unicode',['Unicode',['../structHershey__to__Unicode__table.html#a63927014341b3ba1eec039c34b7cfcb6',1,'Hershey_to_Unicode_table::Unicode()'],['../structUnicode__to__Type1__table.html#afc981b330d66e7885e6452356674822a',1,'Unicode_to_Type1_table::Unicode()']]],
  ['unicode_5farray',['unicode_array',['../structEscText.html#ac5ed6a599aa6688ea4e016d5cf9184d7',1,'EscText']]],
  ['unicode_5farray_5flen',['unicode_array_len',['../structEscText.html#a0226f7ca906eec56ae4068ba37a8542b',1,'EscText']]],
  ['unicode_5fbuffer_5fstatic',['unicode_buffer_static',['../plcore_8c.html#ae30c62e1206957286d289d92feddb783',1,'plcore.c']]],
  ['unicode_5fchar',['unicode_char',['../structEscText.html#ac56ff5804691c224408db9af7c99ecc0',1,'EscText']]],
  ['unicode_5fto_5fdingbats_5flookup_5ftable',['unicode_to_dingbats_lookup_table',['../plunicode-type1_8h.html#a674af18dbdc988c6def70b72f208d90b',1,'plunicode-type1.h']]],
  ['unicode_5fto_5fstandard_5flookup_5ftable',['unicode_to_standard_lookup_table',['../plunicode-type1_8h.html#ade7c8b0082f182f1b4f4cd0c12fab4b9',1,'plunicode-type1.h']]],
  ['unicode_5fto_5fsymbol_5flookup_5ftable',['unicode_to_symbol_lookup_table',['../plunicode-type1_8h.html#a158045056cf63af57aaebb2808629206',1,'plunicode-type1.h']]],
  ['updatecmd',['updatecmd',['../structTkDev.html#a5392c715a876c5d53e17e3a2f468e443',1,'TkDev']]],
  ['updown',['upDown',['../structPLCairo.html#acc53ff3dfd75bceb46c5647814f127d0',1,'PLCairo']]],
  ['urx',['urx',['../structPSDev.html#aa759c208dcaeaebf15e491a48e20de99',1,'PSDev']]],
  ['ury',['ury',['../structPSDev.html#a2a413bbcb369b38931eb0b95f64f5add',1,'PSDev']]],
  ['usage',['usage',['../plargs_8c.html#aef1bd6ad890a110b466cb0e8088507a2',1,'plargs.c']]],
  ['user',['user',['../structPLStream.html#a2c45ef41fca4c2716c99b911c9c8d671',1,'PLStream']]],
  ['utmp',['utmp',['../plot3d_8c.html#a7e3aab59224e9c6116d2c8cc2243fac1',1,'plot3d.c']]]
];
